# Library for validation process monitoring

*Nefertem* is a library that produces a set of [metadata](./docs/source/docs/metadata.rst) during the data validation process operated by some validation framework and allows data and reporting persistence as artifacts.

- [Installation and requirements](./docs/source/docs/installation.rst)
- [Example notebook](./basic_usage_example.ipynb)
- [Client](./docs/source/docs/client.rst)
- [Dataresource](./docs/source/docs/dataresource.rst)
- [Authentication](./docs/source/docs/authentication.rst)
- [Stores](./docs/source/docs/stores.rst)
- [Run](./docs/source/docs/run.rst)
- [Inference](./docs/source/docs/inference.rst)
- [Profiling](./docs/source/docs/profiling.rst)
- [Validation](./docs/source/docs/validation.rst)
- [Constraints](./docs/source/docs/constraints.rst)
